@@ -1,5 +1,5 @@
 package WebService::Async::UserAgent::LWP;
-$WebService::Async::UserAgent::LWP::VERSION = '0.004';
+$WebService::Async::UserAgent::LWP::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ WebService::Async::UserAgent::LWP - make requests using L<LWP::UserAgent>
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -62,7 +62,7 @@ sub ua { shift->{ua} ||= LWP::UserAgent->new }
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
