@@ -1,5 +1,5 @@
 package WebService::Async::UserAgent::MojoUA;
-$WebService::Async::UserAgent::MojoUA::VERSION = '0.004';
+$WebService::Async::UserAgent::MojoUA::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ WebService::Async::UserAgent::MojoUA - make requests using L<Mojo::UserAgent>
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -23,6 +23,7 @@ L<WebService::Async::UserAgent>.
 
 use Future;
 use Mojo::UserAgent;
+use Future::Mojo;
 
 =head2 new
 
@@ -43,14 +44,26 @@ response content on success, or the failure reason on failure.
 sub request {
 	my $self = shift;
 	my $req = shift;
+	my $f = Future::Mojo->new;
 	my $method = lc $req->method;
-	my $resp = $self->ua->$method(''.$req->uri => { map {; $_ => ''.$req->header($_) } $req->header_field_names } => $req->content);
-	if(my $res = $resp->success) {
-		return Future->done($res->body)
-	}
-
-	my $status = join ' ', $resp->error;
-	return Future->fail($status, $resp, $req)
+	$self->ua->$method(
+		''.$req->uri => {
+			map {;
+				$_ => ''.$req->header($_)
+			} $req->header_field_names
+		},
+		$req->content,
+		sub {
+			my ($ua, $tx) = @_;
+			if($tx->success) {
+				$f->done($tx->res->body);
+			} else {
+				my $err = $tx->error;
+				$f->fail(join(' ', @{$err}{qw(code message)}), http => $tx->res);
+			}
+		}
+	);
+	return $f
 }
 
 =head2 ua
@@ -65,7 +78,7 @@ sub ua { shift->{ua} ||= Mojo::UserAgent->new }
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
