@@ -1,5 +1,5 @@
 package WebService::Async::UserAgent::NaHTTP;
-$WebService::Async::UserAgent::NaHTTP::VERSION = '0.004';
+$WebService::Async::UserAgent::NaHTTP::VERSION = '0.005';
 use strict;
 use warnings;
 
@@ -11,7 +11,7 @@ WebService::Async::UserAgent::NaHTTP - make requests using L<Net::Async::HTTP>
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
@@ -87,7 +87,7 @@ sub loop { shift->{loop} }
 
 =head1 AUTHOR
 
-Tom Molesworth <cpan@perlsite.co.uk>
+Tom Molesworth <TEAM@cpan.org>
 
 =head1 LICENSE
 
